@@ -1,5 +1,5 @@
 import json
-from typing import List
+from typing import Any, List, Optional
 
 try:
     from typing import Literal
@@ -7,14 +7,19 @@ except ImportError:
     # Python 3.7 does not support typing.Literal
     from typing_extensions import Literal  # type: ignore
 
-from aqueduct_executor.operators.utils import enums
+from aqueduct_executor.operators.utils.enums import (
+    ArtifactType,
+    CheckSeverity,
+    JobType,
+    OperatorType,
+)
 from aqueduct_executor.operators.utils.storage import config
-from pydantic import BaseModel, Extra, parse_obj_as, validator
+from pydantic import BaseModel, Extra, parse_obj_as
 
 
 class FunctionSpec(BaseModel):
     name: str
-    type: Literal[enums.JobType.FUNCTION]
+    type: Literal[JobType.FUNCTION]
     storage_config: config.StorageConfig
     metadata_path: str
     function_path: str
@@ -27,28 +32,22 @@ class FunctionSpec(BaseModel):
     input_metadata_paths: List[str]
     output_content_paths: List[str]
     output_metadata_paths: List[str]
-    input_artifact_types: List[enums.InputArtifactType]
-    output_artifact_types: List[enums.OutputArtifactType]
+    expected_output_artifact_types: List[ArtifactType]
+    operator_type: OperatorType
+
+    # This is specific to the check operator. This is left unset by any other function type.
+    check_severity: Optional[CheckSeverity]
+
+    # This is always unset - it is only here because we forbid extra fields.
+    resources: Optional[Any]
 
     class Config:
         extra = Extra.forbid
 
-    @validator("output_artifact_types")
-    def check_metric_outputs(
-        cls, output_artifact_types: List[enums.OutputArtifactType]
-    ) -> List[enums.OutputArtifactType]:
-        if (
-            len(output_artifact_types) > 1
-            and enums.OutputArtifactType.FLOAT in output_artifact_types
-        ):
-            raise ValueError("A metric operator cannot have multiple outputs.")
-        return output_artifact_types
-
 
 def parse_spec(spec_json: bytes) -> FunctionSpec:
     """
     Parses a JSON string into a FunctionSpec.
     """
     data = json.loads(spec_json)
-
     return parse_obj_as(FunctionSpec, data)
