@@ -1,13 +1,13 @@
 import json
-from pydantic import BaseModel, parse_obj_as
 from typing import List
 
+from pydantic import BaseModel, parse_obj_as
 
 try:
     from typing import Literal
 except ImportError:
     # Python 3.7 does not support typing.Literal
-    from typing_extensions import Literal
+    from typing_extensions import Literal  # type: ignore
 
 from aqueduct_executor.operators.utils import enums
 from aqueduct_executor.operators.utils.storage import config
@@ -24,7 +24,7 @@ class SystemMetricSpec(BaseModel):
     output_metadata_path: str
 
 
-def parse_spec(spec_json: str) -> SystemMetricSpec:
+def parse_spec(spec_json: bytes) -> SystemMetricSpec:
     """
     Parses a JSON string into a FunctionSpec.
     """
